cabby.cli package — Cabby 0.0.3 documentation

### Navigation

- index
- modules |
- previous |
- Cabby 0.0.3 documentation »
- API documentation »
- cabby package »

# cabby.cli package

## Submodules

## cabby.cli.collections module

`cabby.cli.collections.` `fetch_collections`()

## cabby.cli.commons module

`cabby.cli.commons.` `configure_color_logging`(level, logger_name=None)

`cabby.cli.commons.` `get_basic_arg_parser`()

`cabby.cli.commons.` `is_args_valid`(args)

`cabby.cli.commons.` `prepare_headers`(raw_headers)

`cabby.cli.commons.` `run_client`(parser, run_func)

## cabby.cli.discovery module

`cabby.cli.discovery.` `discover_services`()

## cabby.cli.poll module

`cabby.cli.poll.` `extend_arguments`(parser)

`cabby.cli.poll.` `generate_filename`(collection, content_block)

`cabby.cli.poll.` `poll_content`()

`cabby.cli.poll.` `save_to_dir`(dest_dir, collection, content_block, as_raw)

## cabby.cli.push module

`cabby.cli.push.` `extend_arguments`(parser)

`cabby.cli.push.` `push_content`()

## cabby.cli.subscriptions module

`cabby.cli.subscriptions.` `extend_arguments`(parser)

`cabby.cli.subscriptions.` `manage_subscription`()

## Module contents

### Navigation

- index
- modules |
- previous |
- Cabby 0.0.3 documentation »
- API documentation »
- cabby package »